==> openflowplugin-extension-nicira-0.9.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nx/action/fin/timeout/grouping/NxActionFinTimeout.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.fin.timeout.grouping;
import java.lang.Class;
import java.lang.Integer;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionFinTimeoutGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container nx-action-fin-timeout {
 *   leaf fin-idle-timeout {
 *     type uint16;
 *   }
 *   leaf fin-hard-timeout {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-fin-timeout-grouping/nx-action-fin-timeout</i>
 *
 * <p>To create instances of this class use {@link NxActionFinTimeoutBuilder}.
 * @see NxActionFinTimeoutBuilder
 *
 */
public interface NxActionFinTimeout
    extends
    ChildOf<NxActionFinTimeoutGrouping>,
    Augmentable<NxActionFinTimeout>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-fin-timeout");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.fin.timeout.grouping.NxActionFinTimeout> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.fin.timeout.grouping.NxActionFinTimeout.class;
    }
    
    /**
     * @return <code>java.lang.Integer</code> <code>finIdleTimeout</code>, or <code>null</code> if not present
     */
    @Nullable Integer getFinIdleTimeout();
    
    /**
     * @return <code>java.lang.Integer</code> <code>finHardTimeout</code>, or <code>null</code> if not present
     */
    @Nullable Integer getFinHardTimeout();

}

==> openflowplugin-extension-nicira-0.10.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nx/action/fin/timeout/grouping/NxActionFinTimeout.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.fin.timeout.grouping;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionFinTimeoutGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.common.Uint16;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container nx-action-fin-timeout {
 *   leaf fin-idle-timeout {
 *     type uint16;
 *   }
 *   leaf fin-hard-timeout {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nx-action-fin-timeout-grouping/nx-action-fin-timeout</i>
 *
 * <p>To create instances of this class use {@link NxActionFinTimeoutBuilder}.
 * @see NxActionFinTimeoutBuilder
 *
 */
public interface NxActionFinTimeout
    extends
    ChildOf<NxActionFinTimeoutGrouping>,
    Augmentable<NxActionFinTimeout>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-fin-timeout");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.fin.timeout.grouping.NxActionFinTimeout> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.fin.timeout.grouping.NxActionFinTimeout.class;
    }
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint16</code> <code>finIdleTimeout</code>, or <code>null</code> if not present
     */
    @Nullable Uint16 getFinIdleTimeout();
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint16</code> <code>finHardTimeout</code>, or <code>null</code> if not present
     */
    @Nullable Uint16 getFinHardTimeout();

}
